@@ -20,8 +20,12 @@ def to_snake_case(input_dict):
     new_dict = {}
     if isinstance(input_dict, dict):
         for key, value in input_dict.items():
+            if isinstance(value, dict):
+                value = to_snake_case(value) 
+
             parsed_key = camel_to_snake_case(key)
             new_dict[parsed_key] = value
+            
     return new_dict
 
 def camel_to_snake_case(string):
